==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPaginatorResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaginatorResourceStringsDescription } from "./WebPaginatorResourceStringsDescription";
/**
 * @hidden
 */
var WebPaginatorResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaginatorResourceStringsDescriptionMetadata, _super);
    function WebPaginatorResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaginatorResourceStringsDescriptionMetadata.b = function (a) {
        if (WebPaginatorResourceStringsDescriptionMetadata.a == null) {
            WebPaginatorResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaginatorResourceStringsDescriptionMetadata.c(WebPaginatorResourceStringsDescriptionMetadata.a);
        }
        if (a.j(WebPaginatorResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPaginatorResourceStringsDescriptionMetadata.a);
    };
    WebPaginatorResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaginatorResourceStrings");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Igx_paginator_label", "String");
        a.item("Igx_paginator_pager_text", "String");
        a.item("Igx_paginator_first_page_button_text", "String");
        a.item("Igx_paginator_previous_page_button_text", "String");
        a.item("Igx_paginator_last_page_button_text", "String");
        a.item("Igx_paginator_next_page_button_text", "String");
    };
    WebPaginatorResourceStringsDescriptionMetadata.d = function (a) {
        WebPaginatorResourceStringsDescriptionMetadata.b(a);
        a.aa("WebPaginatorResourceStrings", function () { return new WebPaginatorResourceStringsDescription(); });
        a.z("WebPaginatorResourceStrings", WebPaginatorResourceStringsDescriptionMetadata.a);
    };
    WebPaginatorResourceStringsDescriptionMetadata.$t = markType(WebPaginatorResourceStringsDescriptionMetadata, 'WebPaginatorResourceStringsDescriptionMetadata');
    WebPaginatorResourceStringsDescriptionMetadata.a = null;
    return WebPaginatorResourceStringsDescriptionMetadata;
}(Base));
export { WebPaginatorResourceStringsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPaginatorResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaginatorResourceStringsDescription } from "./WebPaginatorResourceStringsDescription";
/**
 * @hidden
 */
var WebPaginatorResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaginatorResourceStringsDescriptionMetadata, _super);
    function WebPaginatorResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaginatorResourceStringsDescriptionMetadata.b = function (a) {
        if (WebPaginatorResourceStringsDescriptionMetadata.a == null) {
            WebPaginatorResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaginatorResourceStringsDescriptionMetadata.c(WebPaginatorResourceStringsDescriptionMetadata.a);
        }
        if (a.k(WebPaginatorResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaginatorResourceStringsDescriptionMetadata.a);
    };
    WebPaginatorResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaginatorResourceStrings");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Igx_paginator_label", "String");
        a.item("Igx_paginator_pager_text", "String");
        a.item("Igx_paginator_first_page_button_text", "String");
        a.item("Igx_paginator_previous_page_button_text", "String");
        a.item("Igx_paginator_last_page_button_text", "String");
        a.item("Igx_paginator_next_page_button_text", "String");
    };
    WebPaginatorResourceStringsDescriptionMetadata.d = function (a) {
        WebPaginatorResourceStringsDescriptionMetadata.b(a);
        a.ac("WebPaginatorResourceStrings", function () { return new WebPaginatorResourceStringsDescription(); });
        a.ab("WebPaginatorResourceStrings", WebPaginatorResourceStringsDescriptionMetadata.a);
    };
    WebPaginatorResourceStringsDescriptionMetadata.$t = markType(WebPaginatorResourceStringsDescriptionMetadata, 'WebPaginatorResourceStringsDescriptionMetadata');
    WebPaginatorResourceStringsDescriptionMetadata.a = null;
    return WebPaginatorResourceStringsDescriptionMetadata;
}(Base));
export { WebPaginatorResourceStringsDescriptionMetadata };
